summaryrefslogtreecommitdiffstats
path: root/client/lib/popup.js
diff options
context:
space:
mode:
Diffstat (limited to 'client/lib/popup.js')
-rw-r--r--client/lib/popup.js4
1 files changed, 2 insertions, 2 deletions
diff --git a/client/lib/popup.js b/client/lib/popup.js
index 46c137e8..6ec7dfdb 100644
--- a/client/lib/popup.js
+++ b/client/lib/popup.js
@@ -202,9 +202,9 @@ $(document).on('click', function(evt) {
}
});
// Press escape to close the popup.
var bindPopup = function(f) { return _.bind(f, Popup); };
EscapeActions.register('popup',
- bindPopup(Popup.close),
+ bindPopup(Popup.back),
bindPopup(Popup.isOpen)
);
@@ -202,9 +202,9 @@ $(document).on('click', function(evt) {
}
});
-// Press escape to close the popup.
+// Press escape to go back, or close the popup.
var bindPopup = function(f) { return _.bind(f, Popup); };
EscapeActions.register('popup',